from defi_services.abis.dex.sushiswap.factory_v3_abi import SUSHISWAP_V3_ETH_FACTORY_ABI
from defi_services.abis.dex.uniswap.factory_v2_abi import UNISWAP_FACTORY_ABI
from defi_services.abis.dex.uniswap.nft_token_manager_abi import UNISWAP_V3_NFT_TOKEN_MANGAGER_ABI
from defi_services.abis.dex.uniswap.pool_v3_abi import UNISWAP_V3_POOL_ABI

SUSHISWAP_V0_ETH_INFO = {
    'master_chef_address': '0xc2edad668740f1aa35e4d8f227fb8e17dca888cd',
    'reward_token': '0x6b3595068778dd592e39a122f4f5a5cf09c90fe2',
    'forked': 'uniswap-v2'

}

SUSHISWAP_V2_ETH_INFO = {
    'factory_address': '0xc0aee478e3658e2610c5f7a4a2e1777ce9e4f2ac',
    'master_chef_address': '0xef0881ec094552b2e128cf945ef17a6752b4ec5d',
    'reward_token': '0x6b3595068778dd592e39a122f4f5a5cf09c90fe2',
    'forked': 'uniswap-v2'

}

SUSHISWAP_V2_BSC_INFO = {
    'factory_address': '0xc35dadb65012ec5796536bd9864ed8773abc74c4',
    'master_chef_address': '0x5219c5e32b9fff87f29d5a833832c29134464aaa',
    'reward_token': '0x986cdf0fd180b40c4d6aeaa01ab740b996d8b782',
    'forked': 'uniswap-v2'

}

SUSHISWAP_V2_FANTOM_INFO = {
    'factory_address': '0xc35dadb65012ec5796536bd9864ed8773abc74c4',
    'master_chef_address': '0xf731202a3cf7efa9368c2d7bd613926f7a144db5',
    'reward_token': '0xae75a438b2e0cb8bb01ec1e1e376de11d44477cc',
    'forked': 'uniswap-v2'

}

SUSHISWAP_V2_POLYGON_INFO = {
    'factory_address': '0xc35dadb65012ec5796536bd9864ed8773abc74c4',
    'master_chef_address': '0x0769fd68dfb93167989c6f7254cd0d766fb2841f',
    'reward_token': '0x0b3f868e0be5597d5db7feb59e1cadbb0fdda50a',
    'forked': 'uniswap-v2'

}


SUSHISWAP_V2_AVALANCHE_INFO = {
    'factory_address': '0xc35dadb65012ec5796536bd9864ed8773abc74c4',
    'master_chef_address': '0xe11252176cedd4a493aec9767192c06a04a6b04f',
    'reward_token': '0x37b608519f91f70f2eeb0e5ed9af4061722e4f76',
    'forked': 'uniswap-v2'

}

SUSHISWAP_V2_ARBITRUM_INFO = {
    'factory_address': '0xc35dadb65012ec5796536bd9864ed8773abc74c4',
    'master_chef_address': '0xf4d73326c13a4fc5fd7a064217e12780e9bd62c3',
    'reward_token': '0xd4d42f0b6def4ce0383636770ef773390d85c61a',
    'forked': 'uniswap-v2'

}

SUSHISWAP_V3_ETH_INFO = {
    'factory_address': '0xbaceb8ec6b9355dfc0269c18bac9d6e2bdc29c4f',
    'factory_abi': SUSHISWAP_V3_ETH_FACTORY_ABI,
    'NFT_manager_address': '0x2214a42d8e2a1d20635c2cb0664422c528b6a432',
    'NFT_manager_abi': UNISWAP_V3_NFT_TOKEN_MANGAGER_ABI,
    'pool_abi': UNISWAP_V3_POOL_ABI,
    'forked': 'uniswap-v3'

}
SUSHISWAP_V3_BSC_INFO = {
    'factory_address': '0xbaceb8ec6b9355dfc0269c18bac9d6e2bdc29c4f',
    'factory_abi': SUSHISWAP_V3_ETH_FACTORY_ABI,
    'NFT_manager_address': '0x2214a42d8e2a1d20635c2cb0664422c528b6a432',
    'NFT_manager_abi': UNISWAP_V3_NFT_TOKEN_MANGAGER_ABI,
    'pool_abi': UNISWAP_V3_POOL_ABI,
    'forked': 'uniswap-v3'

}
SUSHISWAP_V3_FANTOM_INFO = {
    'factory_address': '0xbaceb8ec6b9355dfc0269c18bac9d6e2bdc29c4f',
    'factory_abi': SUSHISWAP_V3_ETH_FACTORY_ABI,
    'NFT_manager_address': '0x2214a42d8e2a1d20635c2cb0664422c528b6a432',
    'NFT_manager_abi': UNISWAP_V3_NFT_TOKEN_MANGAGER_ABI,
    'pool_abi': UNISWAP_V3_POOL_ABI,
    'forked': 'uniswap-v3'

}
SUSHISWAP_V3_POLYGON_INFO = {
    'factory_address': '0xbaceb8ec6b9355dfc0269c18bac9d6e2bdc29c4f',
    'factory_abi': SUSHISWAP_V3_ETH_FACTORY_ABI,
    'NFT_manager_address': '0x2214a42d8e2a1d20635c2cb0664422c528b6a432',
    'NFT_manager_abi': UNISWAP_V3_NFT_TOKEN_MANGAGER_ABI,
    'pool_abi': UNISWAP_V3_POOL_ABI,
    'forked': 'uniswap-v3'

}

SUSHISWAP_V3_AVALANCHE_INFO = {
    'factory_address': '0xbaceb8ec6b9355dfc0269c18bac9d6e2bdc29c4f',
    'factory_abi': SUSHISWAP_V3_ETH_FACTORY_ABI,
    'NFT_manager_address': '0x2214a42d8e2a1d20635c2cb0664422c528b6a432',
    'NFT_manager_abi': UNISWAP_V3_NFT_TOKEN_MANGAGER_ABI,
    'pool_abi': UNISWAP_V3_POOL_ABI,
    'forked': 'uniswap-v3'

}

SUSHISWAP_V3_ARBITRUM_INFO = {
    'factory_address': '0xbaceb8ec6b9355dfc0269c18bac9d6e2bdc29c4f',
    'factory_abi': SUSHISWAP_V3_ETH_FACTORY_ABI,
    'NFT_manager_address': '0x2214a42d8e2a1d20635c2cb0664422c528b6a432',
    'NFT_manager_abi': UNISWAP_V3_NFT_TOKEN_MANGAGER_ABI,
    'pool_abi': UNISWAP_V3_POOL_ABI,
    'forked': 'uniswap-v3'

}
